# TextEdit-1.2 #
A small module for to display the letters at the sequence.  
The Github Repo with the source code is:[link] (https://github.com/C0rent1Perdry/TextEdit-1.1)  
For windows, you must install the folder TextEdit in C:\Users\you_account\AppData\Local\python\python-version\Lib\  
For Linux, you must install the folder TextEdit in /usr/local/lib/python/dist-packages/  
So, you import TextEdit for Linux with pip3 TextEdit  
And, for Windows you import with python py -m pip install TextEdit  